"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    time_period: Dict,
    group_by: List = None,
    granularity: str = None,
    filter_: Dict = None,
    metrics: List = None,
    next_token: str = None,
    max_results: int = None,
    sort_by: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the Savings Plans covered for your account. This enables you to see how much of your cost is covered by a Savings Plan. An organization’s management account can see the coverage of the associated member accounts. This supports dimensions, Cost Categories, and nested expressions. For any time period, you can filter data for Savings Plans usage with the following dimensions:    LINKED_ACCOUNT     REGION     SERVICE     INSTANCE_FAMILY    To determine valid values for a dimension, use the GetDimensionValues operation.

    Args:
        time_period(Dict): The time period that you want the usage and costs for. The Start date must be within 13 months. The End date must be after the Start date, and before the current date. Future dates can't be used as an End date.
        group_by(List, optional): You can group the data using the attributes INSTANCE_FAMILY, REGION, or SERVICE. Defaults to None.
        granularity(str, optional): The granularity of the Amazon Web Services cost data for your Savings Plans. Granularity can't be set if GroupBy is set. The GetSavingsPlansCoverage operation supports only DAILY and MONTHLY granularities. Defaults to None.
        filter_(Dict, optional): Filters Savings Plans coverage data by dimensions. You can filter data for Savings Plans usage with the following dimensions:    LINKED_ACCOUNT     REGION     SERVICE     INSTANCE_FAMILY     GetSavingsPlansCoverage uses the same Expression object as the other operations, but only AND is supported among each dimension. If there are multiple values for a dimension, they are OR'd together. Cost category is also supported. Defaults to None.
        metrics(List, optional): The measurement that you want your Savings Plans coverage reported in. The only valid value is SpendCoveredBySavingsPlans. Defaults to None.
        next_token(str, optional): The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size. Defaults to None.
        max_results(int, optional): The number of items to be returned in a response. The default is 20, with a minimum value of 1. Defaults to None.
        sort_by(Dict, optional): The value by which you want to sort the data. The following values are supported for Key:    SpendCoveredBySavingsPlan     OnDemandCost     CoveragePercentage     TotalCost     InstanceFamily     Region     Service    Supported values for SortOrder are ASCENDING or DESCENDING. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.saving_plan.coverage.get(ctx, time_period=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.saving_plan.coverage.get time_period=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="get_savings_plans_coverage",
        op_kwargs={
            "TimePeriod": time_period,
            "GroupBy": group_by,
            "Granularity": granularity,
            "Filter": filter_,
            "Metrics": metrics,
            "NextToken": next_token,
            "MaxResults": max_results,
            "SortBy": sort_by,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub, ctx, event_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of accounts in the organization from AWS Organizations that are affected by the provided event. For more information about the different types of AWS Health events, see Event.  Before you can call this operation, you must first enable AWS Health to work with AWS Organizations. To do this, call the EnableHealthServiceAccessForOrganization operation from your organization's management account.  This API operation uses pagination. Specify the nextToken parameter in the next request to return more results.

    Args:
        event_arn(str): The unique identifier for the event. The event ARN has the arn:aws:health:event-region::event/SERVICE/EVENT_TYPE_CODE/EVENT_TYPE_PLUS_ID  format. For example, an event ARN might look like the following:  arn:aws:health:us-east-1::event/EC2/EC2_INSTANCE_RETIREMENT_SCHEDULED/EC2_INSTANCE_RETIREMENT_SCHEDULED_ABC123-DEF456 .
        next_token(str, optional): If the results of a search are large, only a portion of the results are returned, and a nextToken pagination token is returned in the response. To retrieve the next batch of results, reissue the search request and include the returned token. When all results have been returned, the response does not contain a pagination token value. Defaults to None.
        max_results(int, optional): The maximum number of items to return in one batch, between 10 and 100, inclusive. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.health.affected.account_for_organization.describe(
                ctx, event_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.health.affected.account_for_organization.describe event_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="health",
        operation="describe_affected_accounts_for_organization",
        op_kwargs={
            "eventArn": event_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def put(
    hub,
    ctx,
    alarm_name: str,
    alarm_rule: str,
    actions_enabled: bool = None,
    alarm_actions: List = None,
    alarm_description: str = None,
    insufficient_data_actions: List = None,
    ok_actions: List = None,
    tags: List = None,
) -> None:
    r"""
    **Autogenerated function**

    Creates or updates a composite alarm. When you create a composite alarm, you specify a rule expression for the alarm that takes into account the alarm states of other alarms that you have created. The composite alarm goes into ALARM state only if all conditions of the rule are met. The alarms specified in a composite alarm's rule expression can include metric alarms and other composite alarms. Using composite alarms can reduce alarm noise. You can create multiple metric alarms, and also create a composite alarm and set up alerts only for the composite alarm. For example, you could create a composite alarm that goes into ALARM state only when more than one of the underlying metric alarms are in ALARM state. Currently, the only alarm actions that can be taken by composite alarms are notifying SNS topics.  It is possible to create a loop or cycle of composite alarms, where composite alarm A depends on composite alarm B, and composite alarm B also depends on composite alarm A. In this scenario, you can't delete any composite alarm that is part of the cycle because there is always still a composite alarm that depends on that alarm that you want to delete. To get out of such a situation, you must break the cycle by changing the rule of one of the composite alarms in the cycle to remove a dependency that creates the cycle. The simplest change to make to break a cycle is to change the AlarmRule of one of the alarms to False.  Additionally, the evaluation of composite alarms stops if CloudWatch detects a cycle in the evaluation path.   When this operation creates an alarm, the alarm state is immediately set to INSUFFICIENT_DATA. The alarm is then evaluated and its state is set appropriately. Any actions associated with the new state are then executed. For a composite alarm, this initial time after creation is the only time that the alarm can be in INSUFFICIENT_DATA state. When you update an existing alarm, its state is left unchanged, but the update completely overwrites the previous configuration of the alarm. If you are an IAM user, you must have iam:CreateServiceLinkedRole to create a composite alarm that has Systems Manager OpsItem actions.

    Args:
        actions_enabled(bool, optional): Indicates whether actions should be executed during any changes to the alarm state of the composite alarm. The default is TRUE. Defaults to None.
        alarm_actions(List, optional): The actions to execute when this alarm transitions to the ALARM state from any other state. Each action is specified as an Amazon Resource Name (ARN). Valid Values: arn:aws:sns:region:account-id:sns-topic-name  | arn:aws:ssm:region:account-id:opsitem:severity  . Defaults to None.
        alarm_description(str, optional): The description for the composite alarm. Defaults to None.
        alarm_name(str): The name for the composite alarm. This name must be unique within the Region.
        alarm_rule(str): An expression that specifies which other alarms are to be evaluated to determine this composite alarm's state. For each alarm that you reference, you designate a function that specifies whether that alarm needs to be in ALARM state, OK state, or INSUFFICIENT_DATA state. You can use operators (AND, OR and NOT) to combine multiple functions in a single expression. You can use parenthesis to logically group the functions in your expression. You can use either alarm names or ARNs to reference the other alarms that are to be evaluated. Functions can include the following:    ALARM("alarm-name or alarm-ARN") is TRUE if the named alarm is in ALARM state.    OK("alarm-name or alarm-ARN") is TRUE if the named alarm is in OK state.    INSUFFICIENT_DATA("alarm-name or alarm-ARN") is TRUE if the named alarm is in INSUFFICIENT_DATA state.    TRUE always evaluates to TRUE.    FALSE always evaluates to FALSE.   TRUE and FALSE are useful for testing a complex AlarmRule structure, and for testing your alarm actions. Alarm names specified in AlarmRule can be surrounded with double-quotes ("), but do not have to be. The following are some examples of AlarmRule:    ALARM(CPUUtilizationTooHigh) AND ALARM(DiskReadOpsTooHigh) specifies that the composite alarm goes into ALARM state only if both CPUUtilizationTooHigh and DiskReadOpsTooHigh alarms are in ALARM state.    ALARM(CPUUtilizationTooHigh) AND NOT ALARM(DeploymentInProgress) specifies that the alarm goes to ALARM state if CPUUtilizationTooHigh is in ALARM state and DeploymentInProgress is not in ALARM state. This example reduces alarm noise during a known deployment window.    (ALARM(CPUUtilizationTooHigh) OR ALARM(DiskReadOpsTooHigh)) AND OK(NetworkOutTooHigh) goes into ALARM state if CPUUtilizationTooHigh OR DiskReadOpsTooHigh is in ALARM state, and if NetworkOutTooHigh is in OK state. This provides another example of using a composite alarm to prevent noise. This rule ensures that you are not notified with an alarm action on high CPU or disk usage if a known network problem is also occurring.   The AlarmRule can specify as many as 100 "children" alarms. The AlarmRule expression can have as many as 500 elements. Elements are child alarms, TRUE or FALSE statements, and parentheses.
        insufficient_data_actions(List, optional): The actions to execute when this alarm transitions to the INSUFFICIENT_DATA state from any other state. Each action is specified as an Amazon Resource Name (ARN). Valid Values: arn:aws:sns:region:account-id:sns-topic-name  . Defaults to None.
        ok_actions(List, optional): The actions to execute when this alarm transitions to an OK state from any other state. Each action is specified as an Amazon Resource Name (ARN). Valid Values: arn:aws:sns:region:account-id:sns-topic-name  . Defaults to None.
        tags(List, optional): A list of key-value pairs to associate with the composite alarm. You can associate as many as 50 tags with an alarm. Tags can help you organize and categorize your resources. You can also use them to scope user permissions, by granting a user permission to access or change only resources with certain tag values. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.composite_alarm.put(
                ctx, alarm_name=value, alarm_rule=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.composite_alarm.put alarm_name=value, alarm_rule=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="put_composite_alarm",
        op_kwargs={
            "ActionsEnabled": actions_enabled,
            "AlarmActions": alarm_actions,
            "AlarmDescription": alarm_description,
            "AlarmName": alarm_name,
            "AlarmRule": alarm_rule,
            "InsufficientDataActions": insufficient_data_actions,
            "OKActions": ok_actions,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def define(hub, ctx, domain_name: str, analysis_scheme: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Configures an analysis scheme that can be applied to a text or text-array field to define language-specific text processing options. For more information, see Configuring Analysis Schemes in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
        analysis_scheme(Dict): Configuration information for an analysis scheme. Each analysis scheme has a unique name and specifies the language of the text to be processed. The following options can be configured for an analysis scheme: Synonyms, Stopwords, StemmingDictionary, JapaneseTokenizationDictionary and AlgorithmicStemming.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.analysis_scheme.define(
                ctx, domain_name=value, analysis_scheme=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.analysis_scheme.define domain_name=value, analysis_scheme=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="define_analysis_scheme",
        op_kwargs={"DomainName": domain_name, "AnalysisScheme": analysis_scheme},
    )


async def delete(hub, ctx, domain_name: str, analysis_scheme_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an analysis scheme. For more information, see Configuring Analysis Schemes in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
        analysis_scheme_name(str): The name of the analysis scheme you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.analysis_scheme.delete(
                ctx, domain_name=value, analysis_scheme_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.analysis_scheme.delete domain_name=value, analysis_scheme_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="delete_analysis_scheme",
        op_kwargs={
            "DomainName": domain_name,
            "AnalysisSchemeName": analysis_scheme_name,
        },
    )


async def describe_all(
    hub,
    ctx,
    domain_name: str,
    analysis_scheme_names: List = None,
    deployed: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the analysis schemes configured for a domain. An analysis scheme defines language-specific text processing options for a text field. Can be limited to specific analysis schemes by name. By default, shows all analysis schemes and includes any pending changes to the configuration. Set the Deployed option to true to show the active configuration and exclude pending changes. For more information, see Configuring Analysis Schemes in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): The name of the domain you want to describe.
        analysis_scheme_names(List, optional): The analysis schemes you want to describe. Defaults to None.
        deployed(bool, optional): Whether to display the deployed configuration (true) or include any pending changes (false). Defaults to false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.analysis_scheme.describe_all(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.analysis_scheme.describe_all domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="describe_analysis_schemes",
        op_kwargs={
            "DomainName": domain_name,
            "AnalysisSchemeNames": analysis_scheme_names,
            "Deployed": deployed,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, deployment_id: str, group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the status of a deployment.

    Args:
        deployment_id(str): The ID of the deployment.
        group_id(str): The ID of the Greengrass group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.deployment.status.get(
                ctx, deployment_id=value, group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.deployment.status.get deployment_id=value, group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="get_deployment_status",
        op_kwargs={"DeploymentId": deployment_id, "GroupId": group_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    domain_name: str,
    default_expiration_days: int,
    default_encryption_key: str = None,
    dead_letter_queue_url: str = None,
    matching: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a domain, which is a container for all customer data, such as customer profile attributes, object types, profile keys, and encryption keys. You can create multiple domains, and each domain can have multiple third-party integrations. Each Amazon Connect instance can be associated with only one domain. Multiple Amazon Connect instances can be associated with one domain.

    Args:
        domain_name(str): The unique name of the domain.
        default_expiration_days(int): The default number of days until the data within the domain expires.
        default_encryption_key(str, optional): The default encryption key, which is an AWS managed key, is used when no specific type of encryption key is specified. It is used to encrypt all data before it is placed in permanent or semi-permanent storage. Defaults to None.
        dead_letter_queue_url(str, optional): The URL of the SQS dead letter queue, which is used for reporting errors associated with ingesting data from third party applications. You must set up a policy on the DeadLetterQueue for the SendMessage operation to enable Amazon Connect Customer Profiles to send messages to the DeadLetterQueue. Defaults to None.
        matching(Dict, optional): The process of matching duplicate profiles. This process runs every Saturday at 12AM. Defaults to None.
        tags(Dict, optional): The tags used to organize, track, or control access for this resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.domain.create(
                ctx, domain_name=value, default_expiration_days=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.domain.create domain_name=value, default_expiration_days=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="create_domain",
        op_kwargs={
            "DomainName": domain_name,
            "DefaultExpirationDays": default_expiration_days,
            "DefaultEncryptionKey": default_encryption_key,
            "DeadLetterQueueUrl": dead_letter_queue_url,
            "Matching": matching,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specific domain and all of its customer data, such as customer profile attributes and their related objects.

    Args:
        domain_name(str): The unique name of the domain.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.domain.delete(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.domain.delete domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="delete_domain",
        op_kwargs={"DomainName": domain_name},
    )


async def get(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specific domain.

    Args:
        domain_name(str): The unique name of the domain.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.domain.get(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.domain.get domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="get_domain",
        op_kwargs={"DomainName": domain_name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all the domains for an AWS account that have been created.

    Args:
        next_token(str, optional): The pagination token from the previous ListDomain API call. Defaults to None.
        max_results(int, optional): The maximum number of objects returned per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.domain.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.domain.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="list_domains",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(
    hub,
    ctx,
    domain_name: str,
    default_expiration_days: int = None,
    default_encryption_key: str = None,
    dead_letter_queue_url: str = None,
    matching: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the properties of a domain, including creating or selecting a dead letter queue or an encryption key. After a domain is created, the name can’t be changed.

    Args:
        domain_name(str): The unique name of the domain.
        default_expiration_days(int, optional): The default number of days until the data within the domain expires. Defaults to None.
        default_encryption_key(str, optional): The default encryption key, which is an AWS managed key, is used when no specific type of encryption key is specified. It is used to encrypt all data before it is placed in permanent or semi-permanent storage. If specified as an empty string, it will clear any existing value. Defaults to None.
        dead_letter_queue_url(str, optional): The URL of the SQS dead letter queue, which is used for reporting errors associated with ingesting data from third party applications. If specified as an empty string, it will clear any existing value. You must set up a policy on the DeadLetterQueue for the SendMessage operation to enable Amazon Connect Customer Profiles to send messages to the DeadLetterQueue. Defaults to None.
        matching(Dict, optional): The process of matching duplicate profiles. This process runs every Saturday at 12AM. Defaults to None.
        tags(Dict, optional): The tags used to organize, track, or control access for this resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.domain.update(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.domain.update domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="update_domain",
        op_kwargs={
            "DomainName": domain_name,
            "DefaultExpirationDays": default_expiration_days,
            "DefaultEncryptionKey": default_encryption_key,
            "DeadLetterQueueUrl": dead_letter_queue_url,
            "Matching": matching,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Associates a given tag to a resource in your account. A tag is a key-value pair which can be added to an Amazon Lookout for Equipment resource as metadata. Tags can be used for organizing your resources as well as helping you to search and filter by tag. Multiple tags can be added to a resource, either when you create it, or later. Up to 50 tags can be associated with each resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the specific resource to which the tag should be associated. .
        tags(List): The tag or tags to be associated with a specific resource. Both the tag key and value are specified. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.resource.tag(
                ctx, resource_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes a specific tag from a given resource. The tag is specified by its key.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource to which the tag is currently associated. .
        tag_keys(List): Specifies the key of the tag to be removed from a specified resource. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    family_prefix: str = None,
    status: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of task definition families that are registered to your account (which may include task definition families that no longer have any ACTIVE task definition revisions). You can filter out task definition families that do not contain any ACTIVE task definition revisions by setting the status parameter to ACTIVE. You can also filter the results with the familyPrefix parameter.

    Args:
        family_prefix(str, optional): The familyPrefix is a string that is used to filter the results of ListTaskDefinitionFamilies. If you specify a familyPrefix, only task definition family names that begin with the familyPrefix string are returned. Defaults to None.
        status(str, optional): The task definition family status with which to filter the ListTaskDefinitionFamilies results. By default, both ACTIVE and INACTIVE task definition families are listed. If this parameter is set to ACTIVE, only task definition families that have an ACTIVE task definition revision are returned. If this parameter is set to INACTIVE, only task definition families that do not have any ACTIVE task definition revisions are returned. If you paginate the resulting output, be sure to keep the status value constant in each subsequent request. Defaults to None.
        next_token(str, optional): The nextToken value returned from a ListTaskDefinitionFamilies request indicating that more results are available to fulfill the request and further calls will be needed. If maxResults was provided, it is possible the number of results to be fewer than maxResults.  This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.
        max_results(int, optional): The maximum number of task definition family results returned by ListTaskDefinitionFamilies in paginated output. When this parameter is used, ListTaskDefinitions only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListTaskDefinitionFamilies request with the returned nextToken value. This value can be between 1 and 100. If this parameter is not used, then ListTaskDefinitionFamilies returns up to 100 results and a nextToken value if applicable. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.task.definition.family.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.task.definition.family.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="list_task_definition_families",
        op_kwargs={
            "familyPrefix": family_prefix,
            "status": status,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    pipeline_execution_arn: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of parameters for a pipeline execution.

    Args:
        pipeline_execution_arn(str): The Amazon Resource Name (ARN) of the pipeline execution.
        next_token(str, optional): If the result of the previous ListPipelineParametersForExecution request was truncated, the response includes a NextToken. To retrieve the next set of parameters, use the token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of parameters to return in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.pipeline.parameter_for_execution.list(
                ctx, pipeline_execution_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.pipeline.parameter_for_execution.list pipeline_execution_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_pipeline_parameters_for_execution",
        op_kwargs={
            "PipelineExecutionArn": pipeline_execution_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    rest_api_id: str,
    name: str,
    content_type: str,
    description: str = None,
    schema: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a new Model resource to an existing RestApi resource.

    Args:
        rest_api_id(str): [Required] The RestApi identifier under which the Model will be created.
        name(str): [Required] The name of the model. Must be alphanumeric.
        description(str, optional): The description of the model. Defaults to None.
        schema(str, optional): The schema for the model. For application/json models, this should be JSON schema draft 4 model. Defaults to None.
        content_type(str): [Required] The content-type for the model.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.model.init.create(
                ctx, rest_api_id=value, name=value, content_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.model.init.create rest_api_id=value, name=value, content_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="create_model",
        op_kwargs={
            "restApiId": rest_api_id,
            "name": name,
            "description": description,
            "schema": schema,
            "contentType": content_type,
        },
    )


async def delete(hub, ctx, rest_api_id: str, model_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a model.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        model_name(str): [Required] The name of the model to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.model.init.delete(
                ctx, rest_api_id=value, model_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.model.init.delete rest_api_id=value, model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_model",
        op_kwargs={"restApiId": rest_api_id, "modelName": model_name},
    )


async def get(
    hub, ctx, rest_api_id: str, model_name: str, flatten: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes an existing model defined for a RestApi resource.

    Args:
        rest_api_id(str): [Required] The RestApi identifier under which the Model exists.
        model_name(str): [Required] The name of the model as an identifier.
        flatten(bool, optional): A query parameter of a Boolean value to resolve (true) all external model references and returns a flattened model schema or not (false) The default is false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.model.init.get(
                ctx, rest_api_id=value, model_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.model.init.get rest_api_id=value, model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_model",
        op_kwargs={
            "restApiId": rest_api_id,
            "modelName": model_name,
            "flatten": flatten,
        },
    )


async def get_all(
    hub, ctx, rest_api_id: str, position: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes existing Models defined for a RestApi resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        position(str, optional): The current pagination position in the paged result set. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.model.init.get_all(ctx, rest_api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.model.init.get_all rest_api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_models",
        op_kwargs={"restApiId": rest_api_id, "position": position, "limit": limit},
    )


async def update(
    hub, ctx, rest_api_id: str, model_name: str, patch_operations: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Changes information about a model.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        model_name(str): [Required] The name of the model to update.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.model.init.update(
                ctx, rest_api_id=value, model_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.model.init.update rest_api_id=value, model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_model",
        op_kwargs={
            "restApiId": rest_api_id,
            "modelName": model_name,
            "patchOperations": patch_operations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, named_query_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns the details of a single named query or a list of up to 50 queries, which you provide as an array of query ID strings. Requires you to have access to the workgroup in which the queries were saved. Use ListNamedQueriesInput to get the list of named query IDs in the specified workgroup. If information could not be retrieved for a submitted query ID, information about the query ID submitted is listed under UnprocessedNamedQueryId. Named queries differ from executed queries. Use BatchGetQueryExecutionInput to get details about each unique query execution, and ListQueryExecutionsInput to get a list of query execution IDs.

    Args:
        named_query_ids(List): An array of query IDs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.get.named_query.batch(ctx, named_query_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.get.named_query.batch named_query_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="batch_get_named_query",
        op_kwargs={"NamedQueryIds": named_query_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> None:
    r"""
    **Autogenerated function**

    Associates the specified tags to a resource with the specified resourceArn. If existing tags on a resource are not specified in the request parameters, they are not changed. When a resource is deleted, the tags associated with that resource are deleted as well.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) that identifies the AWS Elemental MediaConnect resource to which to add tags.
        tags(Dict): A map from tag keys to values. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Deletes specified tags from a resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) that identifies the AWS Elemental MediaConnect resource from which to delete tags.
        tag_keys(List): The keys of the tags to be removed.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, source_arn: str, description: str = None, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a discoverer.

    Args:
        description(str, optional): A description for the discoverer. Defaults to None.
        source_arn(str): The ARN of the event bus.
        tags(Dict, optional): Tags associated with the resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.discoverer.create(ctx, source_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.discoverer.create source_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="create_discoverer",
        op_kwargs={"Description": description, "SourceArn": source_arn, "Tags": tags},
    )


async def delete(hub, ctx, discoverer_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a discoverer.

    Args:
        discoverer_id(str): The ID of the discoverer.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.discoverer.delete(ctx, discoverer_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.discoverer.delete discoverer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="delete_discoverer",
        op_kwargs={"DiscovererId": discoverer_id},
    )


async def describe(hub, ctx, discoverer_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the discoverer.

    Args:
        discoverer_id(str): The ID of the discoverer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.discoverer.describe(ctx, discoverer_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.discoverer.describe discoverer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="describe_discoverer",
        op_kwargs={"DiscovererId": discoverer_id},
    )


async def list_all(
    hub,
    ctx,
    discoverer_id_prefix: str = None,
    limit: int = None,
    next_token: str = None,
    source_arn_prefix: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List the discoverers.

    Args:
        discoverer_id_prefix(str, optional): Specifying this limits the results to only those discoverer IDs that start with the specified prefix. Defaults to None.
        limit(int, optional): . Defaults to None.
        next_token(str, optional): The token that specifies the next page of results to return. To request the first page, leave NextToken empty. The token will expire in 24 hours, and cannot be shared with other accounts. Defaults to None.
        source_arn_prefix(str, optional): Specifying this limits the results to only those ARNs that start with the specified prefix. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.discoverer.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.discoverer.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="list_discoverers",
        op_kwargs={
            "DiscovererIdPrefix": discoverer_id_prefix,
            "Limit": limit,
            "NextToken": next_token,
            "SourceArnPrefix": source_arn_prefix,
        },
    )


async def start(hub, ctx, discoverer_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts the discoverer

    Args:
        discoverer_id(str): The ID of the discoverer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.discoverer.start(ctx, discoverer_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.discoverer.start discoverer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="start_discoverer",
        op_kwargs={"DiscovererId": discoverer_id},
    )


async def stop(hub, ctx, discoverer_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops the discoverer

    Args:
        discoverer_id(str): The ID of the discoverer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.discoverer.stop(ctx, discoverer_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.discoverer.stop discoverer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="stop_discoverer",
        op_kwargs={"DiscovererId": discoverer_id},
    )


async def update(hub, ctx, discoverer_id: str, description: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the discoverer

    Args:
        description(str, optional): The description of the discoverer to update. Defaults to None.
        discoverer_id(str): The ID of the discoverer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.discoverer.update(ctx, discoverer_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.discoverer.update discoverer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="update_discoverer",
        op_kwargs={"Description": description, "DiscovererId": discoverer_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, queue_url: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of your queues that have the RedrivePolicy queue attribute configured with a dead-letter queue.  The ListDeadLetterSourceQueues methods supports pagination. Set parameter MaxResults in the request to specify the maximum number of results to be returned in the response. If you do not set MaxResults, the response includes a maximum of 1,000 results. If you set MaxResults and there are additional results to display, the response includes a value for NextToken. Use NextToken as a parameter in your next request to ListDeadLetterSourceQueues to receive the next page of results.  For more information about using dead-letter queues, see Using Amazon SQS Dead-Letter Queues in the Amazon SQS Developer Guide.

    Args:
        queue_url(str): The URL of a dead-letter queue. Queue URLs and names are case-sensitive.
        next_token(str, optional): Pagination token to request the next set of results. Defaults to None.
        max_results(int, optional): Maximum number of results to include in the response. Value range is 1 to 1000. You must set MaxResults to receive a value for NextToken in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.dead_letter_source_queue.list_all(ctx, queue_url=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.dead_letter_source_queue.list_all queue_url=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="list_dead_letter_source_queues",
        op_kwargs={
            "QueueUrl": queue_url,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def get_all(hub, ctx, subscription_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns all of the properties of a subscription.

    Args:
        subscription_arn(str): The ARN of the subscription whose properties you want to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.subscription.attribute.get_all(ctx, subscription_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.subscription.attribute.get_all subscription_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="get_subscription_attributes",
        op_kwargs={"SubscriptionArn": subscription_arn},
    )


async def set_(
    hub, ctx, subscription_arn: str, attribute_name: str, attribute_value: str = None
) -> None:
    r"""
    **Autogenerated function**

    Allows a subscription owner to set an attribute of the subscription to a new value.

    Args:
        subscription_arn(str): The ARN of the subscription to modify.
        attribute_name(str): A map of attributes with their corresponding values. The following lists the names, descriptions, and values of the special request parameters that this action uses:    DeliveryPolicy – The policy that defines how Amazon SNS retries failed deliveries to HTTP/S endpoints.    FilterPolicy – The simple JSON object that lets your subscriber receive only a subset of messages, rather than receiving every message published to the topic.    RawMessageDelivery – When set to true, enables raw message delivery to Amazon SQS or HTTP/S endpoints. This eliminates the need for the endpoints to process JSON formatting, which is otherwise created for Amazon SNS metadata.    RedrivePolicy – When specified, sends undeliverable messages to the specified Amazon SQS dead-letter queue. Messages that can't be delivered due to client errors (for example, when the subscribed endpoint is unreachable) or server errors (for example, when the service that powers the subscribed endpoint becomes unavailable) are held in the dead-letter queue for further analysis or reprocessing.   The following attribute applies only to Amazon Kinesis Data Firehose delivery stream subscriptions:    SubscriptionRoleArn – The ARN of the IAM role that has the following:   Permission to write to the Kinesis Data Firehose delivery stream   Amazon SNS listed as a trusted entity   Specifying a valid ARN for this attribute is required for Kinesis Data Firehose delivery stream subscriptions. For more information, see Fanout to Kinesis Data Firehose delivery streams in the Amazon SNS Developer Guide.  .
        attribute_value(str, optional): The new value for the attribute in JSON format. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.subscription.attribute.set(
                ctx, subscription_arn=value, attribute_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.subscription.attribute.set subscription_arn=value, attribute_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="set_subscription_attributes",
        op_kwargs={
            "SubscriptionArn": subscription_arn,
            "AttributeName": attribute_name,
            "AttributeValue": attribute_value,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    bot_name: str,
    next_token: str = None,
    max_results: int = None,
    name_contains: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of aliases for a specified Amazon Lex bot. This operation requires permissions for the lex:GetBotAliases action.

    Args:
        bot_name(str): The name of the bot.
        next_token(str, optional): A pagination token for fetching the next page of aliases. If the response to this call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of aliases, specify the pagination token in the next request. . Defaults to None.
        max_results(int, optional): The maximum number of aliases to return in the response. The default is 50. . . Defaults to None.
        name_contains(str, optional): Substring to match in bot alias names. An alias will be returned if any part of its name matches the substring. For example, "xyz" matches both "xyzabc" and "abcxyz.". Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.bot.aliase.get_all(ctx, bot_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.bot.aliase.get_all bot_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_bot_aliases",
        op_kwargs={
            "botName": bot_name,
            "nextToken": next_token,
            "maxResults": max_results,
            "nameContains": name_contains,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def search(
    hub,
    ctx,
    resource: str,
    search_expression: Dict = None,
    sort_by: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Finds Amazon SageMaker resources that match a search query. Matching resources are returned as a list of SearchRecord objects in the response. You can sort the search results by any resource property in a ascending or descending order. You can query against the following value types: numeric, text, Boolean, and timestamp.

    Args:
        resource(str): The name of the Amazon SageMaker resource to search for.
        search_expression(Dict, optional): A Boolean conditional statement. Resources must satisfy this condition to be included in search results. You must provide at least one subexpression, filter, or nested filter. The maximum number of recursive SubExpressions, NestedFilters, and Filters that can be included in a SearchExpression object is 50. Defaults to None.
        sort_by(str, optional): The name of the resource property used to sort the SearchResults. The default is LastModifiedTime. Defaults to None.
        sort_order(str, optional): How SearchResults are ordered. Valid values are Ascending or Descending. The default is Descending. Defaults to None.
        next_token(str, optional): If more than MaxResults resources match the specified SearchExpression, the response includes a NextToken. The NextToken can be passed to the next SearchRequest to continue retrieving results. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.init.search(ctx, resource=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.init.search resource=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="search",
        op_kwargs={
            "Resource": resource,
            "SearchExpression": search_expression,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"import_": "import"}


async def delete(hub, ctx, name: str) -> None:
    r"""
    **Autogenerated function**

    A synchronous action that deletes a custom terminology.

    Args:
        name(str): The name of the custom terminology being deleted. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.translate.terminology.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.translate.terminology.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="translate",
        operation="delete_terminology",
        op_kwargs={"Name": name},
    )


async def get(hub, ctx, name: str, terminology_data_format: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a custom terminology.

    Args:
        name(str): The name of the custom terminology being retrieved.
        terminology_data_format(str): The data format of the custom terminology being retrieved, either CSV or TMX.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.translate.terminology.get(ctx, name=value, terminology_data_format=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.translate.terminology.get name=value, terminology_data_format=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="translate",
        operation="get_terminology",
        op_kwargs={"Name": name, "TerminologyDataFormat": terminology_data_format},
    )


async def import_(
    hub,
    ctx,
    name: str,
    merge_strategy: str,
    terminology_data: Dict,
    description: str = None,
    encryption_key: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates a custom terminology, depending on whether or not one already exists for the given terminology name. Importing a terminology with the same name as an existing one will merge the terminologies based on the chosen merge strategy. Currently, the only supported merge strategy is OVERWRITE, and so the imported terminology will overwrite an existing terminology of the same name. If you import a terminology that overwrites an existing one, the new terminology take up to 10 minutes to fully propagate and be available for use in a translation due to cache policies with the DataPlane service that performs the translations.

    Args:
        name(str): The name of the custom terminology being imported.
        merge_strategy(str): The merge strategy of the custom terminology being imported. Currently, only the OVERWRITE merge strategy is supported. In this case, the imported terminology will overwrite an existing terminology of the same name.
        description(str, optional): The description of the custom terminology being imported. Defaults to None.
        terminology_data(Dict): The terminology data for the custom terminology being imported.
        encryption_key(Dict, optional): The encryption key for the custom terminology being imported. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.translate.terminology.import(ctx, name=value, merge_strategy=value, terminology_data=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.translate.terminology.import name=value, merge_strategy=value, terminology_data=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="translate",
        operation="import_terminology",
        op_kwargs={
            "Name": name,
            "MergeStrategy": merge_strategy,
            "Description": description,
            "TerminologyData": terminology_data,
            "EncryptionKey": encryption_key,
        },
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Provides a list of custom terminologies associated with your account.

    Args:
        next_token(str, optional): If the result of the request to ListTerminologies was truncated, include the NextToken to fetch the next group of custom terminologies. . Defaults to None.
        max_results(int, optional): The maximum number of custom terminologies returned per list request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.translate.terminology.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.translate.terminology.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="translate",
        operation="list_terminologies",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    fleet_id: str,
    instance_id: str = None,
    limit: int = None,
    next_token: str = None,
    location: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a fleet's instances, including instance IDs, connection data, and status.  This operation can be used in the following ways:   To get information on all instances that are deployed to a fleet's home Region, provide the fleet ID.   To get information on all instances that are deployed to a fleet's remote location, provide the fleet ID and location name.   To get information on a specific instance in a fleet, provide the fleet ID and instance ID.   Use the pagination parameters to retrieve results as a set of sequential pages.  If successful, an Instance object is returned for each requested instance. Instances are not returned in any particular order.   Learn more   Remotely Access Fleet Instances   Debug Fleet Issues   Related actions   DescribeInstances | GetInstanceAccess | DescribeEC2InstanceLimits | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet to retrieve instance information for. You can use either the fleet ID or ARN value.
        instance_id(str, optional): A unique identifier for an instance to retrieve. Specify an instance ID or leave blank to retrieve all instances in the fleet. Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. Defaults to None.
        location(str, optional): The name of a location to retrieve instance information for, in the form of an AWS Region code such as us-west-2. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.instance.init.describe_all(ctx, fleet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.instance.init.describe_all fleet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_instances",
        op_kwargs={
            "FleetId": fleet_id,
            "InstanceId": instance_id,
            "Limit": limit,
            "NextToken": next_token,
            "Location": location,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def deregister(
    hub, ctx, container_instance: str, cluster: str = None, force: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deregisters an Amazon ECS container instance from the specified cluster. This instance is no longer available to run tasks. If you intend to use the container instance for some other purpose after deregistration, you should stop all of the tasks running on the container instance before deregistration. That prevents any orphaned tasks from consuming resources. Deregistering a container instance removes the instance from a cluster, but it does not terminate the EC2 instance. If you are finished using the instance, be sure to terminate it in the Amazon EC2 console to stop billing.  If you terminate a running container instance, Amazon ECS automatically deregisters the instance from your cluster (stopped container instances or instances with disconnected agents are not automatically deregistered when terminated).

    Args:
        cluster(str, optional): The short name or full Amazon Resource Name (ARN) of the cluster that hosts the container instance to deregister. If you do not specify a cluster, the default cluster is assumed. Defaults to None.
        container_instance(str): The container instance ID or full ARN of the container instance to deregister. The ARN contains the arn:aws:ecs namespace, followed by the Region of the container instance, the account ID of the container instance owner, the container-instance namespace, and then the container instance ID. For example, arn:aws:ecs:region:aws_account_id:container-instance/container_instance_ID.
        force(bool, optional): Forces the deregistration of the container instance. If you have tasks running on the container instance when you deregister it with the force option, these tasks remain running until you terminate the instance or the tasks stop through some other means, but they are orphaned (no longer monitored or accounted for by Amazon ECS). If an orphaned task on your container instance is part of an Amazon ECS service, then the service scheduler starts another copy of that task, on a different container instance if possible.  Any containers in orphaned service tasks that are registered with a Classic Load Balancer or an Application Load Balancer target group are deregistered. They begin connection draining according to the settings on the load balancer or target group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.container.instance.init.deregister(
                ctx, container_instance=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.container.instance.init.deregister container_instance=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="deregister_container_instance",
        op_kwargs={
            "cluster": cluster,
            "containerInstance": container_instance,
            "force": force,
        },
    )


async def describe_all(
    hub, ctx, container_instances: List, cluster: str = None, include: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more container instances. Returns metadata about each container instance requested.

    Args:
        cluster(str, optional): The short name or full Amazon Resource Name (ARN) of the cluster that hosts the container instances to describe. If you do not specify a cluster, the default cluster is assumed. This parameter is required if the container instance or container instances you are describing were launched in any cluster other than the default cluster. Defaults to None.
        container_instances(List): A list of up to 100 container instance IDs or full Amazon Resource Name (ARN) entries.
        include(List, optional): Specifies whether you want to see the resource tags for the container instance. If TAGS is specified, the tags are included in the response. If this field is omitted, tags are not included in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.container.instance.init.describe_all(
                ctx, container_instances=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.container.instance.init.describe_all container_instances=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="describe_container_instances",
        op_kwargs={
            "cluster": cluster,
            "containerInstances": container_instances,
            "include": include,
        },
    )


async def list_all(
    hub,
    ctx,
    cluster: str = None,
    filter_: str = None,
    next_token: str = None,
    max_results: int = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of container instances in a specified cluster. You can filter the results of a ListContainerInstances operation with cluster query language statements inside the filter parameter. For more information, see Cluster Query Language in the Amazon Elastic Container Service Developer Guide.

    Args:
        cluster(str, optional): The short name or full Amazon Resource Name (ARN) of the cluster that hosts the container instances to list. If you do not specify a cluster, the default cluster is assumed. Defaults to None.
        filter_(str, optional): You can filter the results of a ListContainerInstances operation with cluster query language statements. For more information, see Cluster Query Language in the Amazon Elastic Container Service Developer Guide. Defaults to None.
        next_token(str, optional): The nextToken value returned from a ListContainerInstances request indicating that more results are available to fulfill the request and further calls will be needed. If maxResults was provided, it is possible the number of results to be fewer than maxResults.  This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.
        max_results(int, optional): The maximum number of container instance results returned by ListContainerInstances in paginated output. When this parameter is used, ListContainerInstances only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListContainerInstances request with the returned nextToken value. This value can be between 1 and 100. If this parameter is not used, then ListContainerInstances returns up to 100 results and a nextToken value if applicable. Defaults to None.
        status(str, optional): Filters the container instances by status. For example, if you specify the DRAINING status, the results include only container instances that have been set to DRAINING using UpdateContainerInstancesState. If you do not specify this parameter, the default is to include container instances set to all states other than INACTIVE. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.container.instance.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.container.instance.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="list_container_instances",
        op_kwargs={
            "cluster": cluster,
            "filter": filter_,
            "nextToken": next_token,
            "maxResults": max_results,
            "status": status,
        },
    )


async def register(
    hub,
    ctx,
    cluster: str = None,
    instance_identity_document: str = None,
    instance_identity_document_signature: str = None,
    total_resources: List = None,
    version_info: Dict = None,
    container_instance_arn: str = None,
    attributes: List = None,
    platform_devices: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This action is only used by the Amazon ECS agent, and it is not intended for use outside of the agent.  Registers an EC2 instance into the specified cluster. This instance becomes available to place containers on.

    Args:
        cluster(str, optional): The short name or full Amazon Resource Name (ARN) of the cluster with which to register your container instance. If you do not specify a cluster, the default cluster is assumed. Defaults to None.
        instance_identity_document(str, optional): The instance identity document for the EC2 instance to register. This document can be found by running the following command from the instance: curl http://169.254.169.254/latest/dynamic/instance-identity/document/ . Defaults to None.
        instance_identity_document_signature(str, optional): The instance identity document signature for the EC2 instance to register. This signature can be found by running the following command from the instance: curl http://169.254.169.254/latest/dynamic/instance-identity/signature/ . Defaults to None.
        total_resources(List, optional): The resources available on the instance. Defaults to None.
        version_info(Dict, optional): The version information for the Amazon ECS container agent and Docker daemon running on the container instance. Defaults to None.
        container_instance_arn(str, optional): The ARN of the container instance (if it was previously registered). Defaults to None.
        attributes(List, optional): The container instance attributes that this container instance supports. Defaults to None.
        platform_devices(List, optional): The devices that are available on the container instance. The only supported device type is a GPU. Defaults to None.
        tags(List, optional): The metadata that you apply to the container instance to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. The following basic restrictions apply to tags:   Maximum number of tags per resource - 50   For each resource, each tag key must be unique, and each tag key can have only one value.   Maximum key length - 128 Unicode characters in UTF-8   Maximum value length - 256 Unicode characters in UTF-8   If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.   Tag keys and values are case-sensitive.   Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for Amazon Web Services use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.container.instance.init.register(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.container.instance.init.register
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="register_container_instance",
        op_kwargs={
            "cluster": cluster,
            "instanceIdentityDocument": instance_identity_document,
            "instanceIdentityDocumentSignature": instance_identity_document_signature,
            "totalResources": total_resources,
            "versionInfo": version_info,
            "containerInstanceArn": container_instance_arn,
            "attributes": attributes,
            "platformDevices": platform_devices,
            "tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete_multiple(hub, ctx, web_acl_arn: str, web_acl_lock_token: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes all rule groups that are managed by Firewall Manager for the specified web ACL.  You can only use this if ManagedByFirewallManager is false in the specified WebACL.

    Args:
        web_acl_arn(str): The Amazon Resource Name (ARN) of the web ACL.
        web_acl_lock_token(str): A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.firewall_manager_rule_group.delete_multiple(
                ctx, web_acl_arn=value, web_acl_lock_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.firewall_manager_rule_group.delete_multiple web_acl_arn=value, web_acl_lock_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="delete_firewall_manager_rule_groups",
        op_kwargs={"WebACLArn": web_acl_arn, "WebACLLockToken": web_acl_lock_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, access_token: str = None, session: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a unique generated shared secret key code for the user account. The request takes an access token or a session string, but not both.  Calling AssociateSoftwareToken immediately disassociates the existing software token from the user account. If the user doesn't subsequently verify the software token, their account is essentially set up to authenticate without MFA. If MFA config is set to Optional at the user pool level, the user can then login without MFA. However, if MFA is set to Required for the user pool, the user will be asked to setup a new software token MFA during sign in.

    Args:
        access_token(str, optional): The access token. Defaults to None.
        session(str, optional): The session which should be passed both ways in challenge-response calls to the service. This allows authentication of the user as part of the MFA setup process. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.software_token.associate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.software_token.associate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="associate_software_token",
        op_kwargs={"AccessToken": access_token, "Session": session},
    )


async def verify(
    hub,
    ctx,
    user_code: str,
    access_token: str = None,
    session: str = None,
    friendly_device_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Use this API to register a user's entered TOTP code and mark the user's software token MFA status as "verified" if successful. The request takes an access token or a session string, but not both.

    Args:
        access_token(str, optional): The access token. Defaults to None.
        session(str, optional): The session which should be passed both ways in challenge-response calls to the service. Defaults to None.
        user_code(str): The one time password computed using the secret code returned by AssociateSoftwareToken".
        friendly_device_name(str, optional): The friendly device name. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.software_token.verify(ctx, user_code=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.software_token.verify user_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="verify_software_token",
        op_kwargs={
            "AccessToken": access_token,
            "Session": session,
            "UserCode": user_code,
            "FriendlyDeviceName": friendly_device_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub,
    ctx,
    language: str,
    registry_name: str,
    schema_name: str,
    schema_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describe the code binding URI.

    Args:
        language(str): The language of the code binding.
        registry_name(str): The name of the registry.
        schema_name(str): The name of the schema.
        schema_version(str, optional): Specifying this limits the results to only this schema version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.code_binding.init.describe(
                ctx, language=value, registry_name=value, schema_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.code_binding.init.describe language=value, registry_name=value, schema_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="describe_code_binding",
        op_kwargs={
            "Language": language,
            "RegistryName": registry_name,
            "SchemaName": schema_name,
            "SchemaVersion": schema_version,
        },
    )


async def put(
    hub,
    ctx,
    language: str,
    registry_name: str,
    schema_name: str,
    schema_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Put code binding URI

    Args:
        language(str): The language of the code binding.
        registry_name(str): The name of the registry.
        schema_name(str): The name of the schema.
        schema_version(str, optional): Specifying this limits the results to only this schema version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.code_binding.init.put(
                ctx, language=value, registry_name=value, schema_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.code_binding.init.put language=value, registry_name=value, schema_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="put_code_binding",
        op_kwargs={
            "Language": language,
            "RegistryName": registry_name,
            "SchemaName": schema_name,
            "SchemaVersion": schema_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    instance_id: str,
    start_time: str,
    end_time: str,
    filters: Dict,
    historical_metrics: List,
    groupings: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets historical metric data from the specified Amazon Connect instance. For a description of each historical metric, see Historical Metrics Definitions in the Amazon Connect Administrator Guide.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        start_time(str): The timestamp, in UNIX Epoch time format, at which to start the reporting interval for the retrieval of historical metrics data. The time must be specified using a multiple of 5 minutes, such as 10:05, 10:10, 10:15. The start time cannot be earlier than 24 hours before the time of the request. Historical metrics are available only for 24 hours.
        end_time(str): The timestamp, in UNIX Epoch time format, at which to end the reporting interval for the retrieval of historical metrics data. The time must be specified using an interval of 5 minutes, such as 11:00, 11:05, 11:10, and must be later than the start time timestamp. The time range between the start and end time must be less than 24 hours.
        filters(Dict): The queues, up to 100, or channels, to use to filter the metrics returned. Metric data is retrieved only for the resources associated with the queues or channels included in the filter. You can include both queue IDs and queue ARNs in the same request. VOICE, CHAT, and TASK channels are supported.  To filter by Queues, enter the queue ID/ARN, not the name of the queue. .
        groupings(List, optional): The grouping applied to the metrics returned. For example, when results are grouped by queue, the metrics returned are grouped by queue. The values returned apply to the metrics for each queue rather than aggregated for all queues. If no grouping is specified, a summary of metrics for all queues is returned. Defaults to None.
        historical_metrics(List): The metrics to retrieve. Specify the name, unit, and statistic for each metric. The following historical metrics are available. For a description of each metric, see Historical Metrics Definitions in the Amazon Connect Administrator Guide.  This API does not support a contacts incoming metric (there's no CONTACTS_INCOMING metric missing from the documented list).    ABANDON_TIME  Unit: SECONDS Statistic: AVG  AFTER_CONTACT_WORK_TIME  Unit: SECONDS Statistic: AVG  API_CONTACTS_HANDLED  Unit: COUNT Statistic: SUM  CALLBACK_CONTACTS_HANDLED  Unit: COUNT Statistic: SUM  CONTACTS_ABANDONED  Unit: COUNT Statistic: SUM  CONTACTS_AGENT_HUNG_UP_FIRST  Unit: COUNT Statistic: SUM  CONTACTS_CONSULTED  Unit: COUNT Statistic: SUM  CONTACTS_HANDLED  Unit: COUNT Statistic: SUM  CONTACTS_HANDLED_INCOMING  Unit: COUNT Statistic: SUM  CONTACTS_HANDLED_OUTBOUND  Unit: COUNT Statistic: SUM  CONTACTS_HOLD_ABANDONS  Unit: COUNT Statistic: SUM  CONTACTS_MISSED  Unit: COUNT Statistic: SUM  CONTACTS_QUEUED  Unit: COUNT Statistic: SUM  CONTACTS_TRANSFERRED_IN  Unit: COUNT Statistic: SUM  CONTACTS_TRANSFERRED_IN_FROM_QUEUE  Unit: COUNT Statistic: SUM  CONTACTS_TRANSFERRED_OUT  Unit: COUNT Statistic: SUM  CONTACTS_TRANSFERRED_OUT_FROM_QUEUE  Unit: COUNT Statistic: SUM  HANDLE_TIME  Unit: SECONDS Statistic: AVG  HOLD_TIME  Unit: SECONDS Statistic: AVG  INTERACTION_AND_HOLD_TIME  Unit: SECONDS Statistic: AVG  INTERACTION_TIME  Unit: SECONDS Statistic: AVG  OCCUPANCY  Unit: PERCENT Statistic: AVG  QUEUE_ANSWER_TIME  Unit: SECONDS Statistic: AVG  QUEUED_TIME  Unit: SECONDS Statistic: MAX  SERVICE_LEVEL  You can include up to 20 SERVICE_LEVEL metrics in a request. Unit: PERCENT Statistic: AVG Threshold: For ThresholdValue, enter any whole number from 1 to 604800 (inclusive), in seconds. For Comparison, you must enter LT (for "Less than").   .
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.metric_data.get(
                ctx,
                instance_id=value,
                start_time=value,
                end_time=value,
                filters=value,
                historical_metrics=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.metric_data.get instance_id=value, start_time=value, end_time=value, filters=value, historical_metrics=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="get_metric_data",
        op_kwargs={
            "InstanceId": instance_id,
            "StartTime": start_time,
            "EndTime": end_time,
            "Filters": filters,
            "Groupings": groupings,
            "HistoricalMetrics": historical_metrics,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, target_group_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the attributes for the specified target group. For more information, see the following:    Target group attributes in the Application Load Balancers Guide     Target group attributes in the Network Load Balancers Guide     Target group attributes in the Gateway Load Balancers Guide

    Args:
        target_group_arn(str): The Amazon Resource Name (ARN) of the target group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.target.group.attribute.describe_all(
                ctx, target_group_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.target.group.attribute.describe_all target_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="describe_target_group_attributes",
        op_kwargs={"TargetGroupArn": target_group_arn},
    )


async def modify(hub, ctx, target_group_arn: str, attributes: List) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the specified attributes of the specified target group.

    Args:
        target_group_arn(str): The Amazon Resource Name (ARN) of the target group.
        attributes(List): The attributes.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.target.group.attribute.modify(
                ctx, target_group_arn=value, attributes=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.target.group.attribute.modify target_group_arn=value, attributes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="modify_target_group_attributes",
        op_kwargs={"TargetGroupArn": target_group_arn, "Attributes": attributes},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "type"


async def disable(hub, ctx, root_id: str, policy_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables an organizational policy type in a root. A policy of a certain type can be attached to entities in a root only if that type is enabled in the root. After you perform this operation, you no longer can attach policies of the specified type to that root or to any organizational unit (OU) or account in that root. You can undo this by using the EnablePolicyType operation. This is an asynchronous request that AWS performs in the background. If you disable a policy type for a root, it still appears enabled for the organization if all features are enabled for the organization. AWS recommends that you first use ListRoots to see the status of policy types for a specified root, and then use this operation. This operation can be called only from the organization's management account.  To view the status of available policy types in the organization, use DescribeOrganization.

    Args:
        root_id(str): The unique identifier (ID) of the root in which you want to disable a policy type. You can get the ID from the ListRoots operation. The regex pattern for a root ID string requires "r-" followed by from 4 to 32 lowercase letters or digits.
        policy_type(str): The policy type that you want to disable in this root. You can specify one of the following values:    AISERVICES_OPT_OUT_POLICY     BACKUP_POLICY     SERVICE_CONTROL_POLICY     TAG_POLICY   .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.policy.type_.disable(
                ctx, root_id=value, policy_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.policy.type.disable root_id=value, policy_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="disable_policy_type",
        op_kwargs={"RootId": root_id, "PolicyType": policy_type},
    )


async def enable(hub, ctx, root_id: str, policy_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Enables a policy type in a root. After you enable a policy type in a root, you can attach policies of that type to the root, any organizational unit (OU), or account in that root. You can undo this by using the DisablePolicyType operation. This is an asynchronous request that AWS performs in the background. AWS recommends that you first use ListRoots to see the status of policy types for a specified root, and then use this operation. This operation can be called only from the organization's management account. You can enable a policy type in a root only if that policy type is available in the organization. To view the status of available policy types in the organization, use DescribeOrganization.

    Args:
        root_id(str): The unique identifier (ID) of the root in which you want to enable a policy type. You can get the ID from the ListRoots operation. The regex pattern for a root ID string requires "r-" followed by from 4 to 32 lowercase letters or digits.
        policy_type(str): The policy type that you want to enable. You can specify one of the following values:    AISERVICES_OPT_OUT_POLICY     BACKUP_POLICY     SERVICE_CONTROL_POLICY     TAG_POLICY   .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.policy.type_.enable(
                ctx, root_id=value, policy_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.policy.type.enable root_id=value, policy_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="enable_policy_type",
        op_kwargs={"RootId": root_id, "PolicyType": policy_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def classify(hub, ctx, text: str, endpoint_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new document classification request to analyze a single document in real-time, using a previously created and trained custom model and an endpoint.

    Args:
        text(str): The document text to be analyzed.
        endpoint_arn(str): The Amazon Resource Number (ARN) of the endpoint.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.document.init.classify(
                ctx, text=value, endpoint_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.document.init.classify text=value, endpoint_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="classify_document",
        op_kwargs={"Text": text, "EndpointArn": endpoint_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    cluster_name: str,
    node_type: str,
    replication_factor: int,
    iam_role_arn: str,
    description: str = None,
    availability_zones: List = None,
    subnet_group_name: str = None,
    security_group_ids: List = None,
    preferred_maintenance_window: str = None,
    notification_topic_arn: str = None,
    parameter_group_name: str = None,
    tags: List = None,
    sse_specification: Dict = None,
    cluster_endpoint_encryption_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a DAX cluster. All nodes in the cluster run the same DAX caching software.

    Args:
        cluster_name(str): The cluster identifier. This parameter is stored as a lowercase string.  Constraints:    A name must contain from 1 to 20 alphanumeric characters or hyphens.   The first character must be a letter.   A name cannot end with a hyphen or contain two consecutive hyphens.  .
        node_type(str): The compute and memory capacity of the nodes in the cluster.
        description(str, optional): A description of the cluster. Defaults to None.
        replication_factor(int): The number of nodes in the DAX cluster. A replication factor of 1 will create a single-node cluster, without any read replicas. For additional fault tolerance, you can create a multiple node cluster with one or more read replicas. To do this, set ReplicationFactor to a number between 3 (one primary and two read replicas) and 10 (one primary and nine read replicas). If the AvailabilityZones parameter is provided, its length must equal the ReplicationFactor.  AWS recommends that you have at least two read replicas per cluster. .
        availability_zones(List, optional): The Availability Zones (AZs) in which the cluster nodes will reside after the cluster has been created or updated. If provided, the length of this list must equal the ReplicationFactor parameter. If you omit this parameter, DAX will spread the nodes across Availability Zones for the highest availability. Defaults to None.
        subnet_group_name(str, optional): The name of the subnet group to be used for the replication group.  DAX clusters can only run in an Amazon VPC environment. All of the subnets that you specify in a subnet group must exist in the same VPC. . Defaults to None.
        security_group_ids(List, optional): A list of security group IDs to be assigned to each node in the DAX cluster. (Each of the security group ID is system-generated.) If this parameter is not specified, DAX assigns the default VPC security group to each node. Defaults to None.
        preferred_maintenance_window(str, optional): Specifies the weekly time range during which maintenance on the DAX cluster is performed. It is specified as a range in the format ddd:hh24:mi-ddd:hh24:mi (24H Clock UTC). The minimum maintenance window is a 60 minute period. Valid values for ddd are:    sun     mon     tue     wed     thu     fri     sat    Example: sun:05:00-sun:09:00   If you don't specify a preferred maintenance window when you create or modify a cache cluster, DAX assigns a 60-minute maintenance window on a randomly selected day of the week. . Defaults to None.
        notification_topic_arn(str, optional): The Amazon Resource Name (ARN) of the Amazon SNS topic to which notifications will be sent.  The Amazon SNS topic owner must be same as the DAX cluster owner. . Defaults to None.
        iam_role_arn(str): A valid Amazon Resource Name (ARN) that identifies an IAM role. At runtime, DAX will assume this role and use the role's permissions to access DynamoDB on your behalf.
        parameter_group_name(str, optional): The parameter group to be associated with the DAX cluster. Defaults to None.
        tags(List, optional): A set of tags to associate with the DAX cluster. . Defaults to None.
        sse_specification(Dict, optional): Represents the settings used to enable server-side encryption on the cluster. Defaults to None.
        cluster_endpoint_encryption_type(str, optional): The type of encryption the cluster's endpoint should support. Values are:    NONE for no encryption    TLS for Transport Layer Security  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dax.cluster.create(
                ctx,
                cluster_name=value,
                node_type=value,
                replication_factor=value,
                iam_role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dax.cluster.create cluster_name=value, node_type=value, replication_factor=value, iam_role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dax",
        operation="create_cluster",
        op_kwargs={
            "ClusterName": cluster_name,
            "NodeType": node_type,
            "Description": description,
            "ReplicationFactor": replication_factor,
            "AvailabilityZones": availability_zones,
            "SubnetGroupName": subnet_group_name,
            "SecurityGroupIds": security_group_ids,
            "PreferredMaintenanceWindow": preferred_maintenance_window,
            "NotificationTopicArn": notification_topic_arn,
            "IamRoleArn": iam_role_arn,
            "ParameterGroupName": parameter_group_name,
            "Tags": tags,
            "SSESpecification": sse_specification,
            "ClusterEndpointEncryptionType": cluster_endpoint_encryption_type,
        },
    )


async def delete(hub, ctx, cluster_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a previously provisioned DAX cluster. DeleteCluster deletes all associated nodes, node endpoints and the DAX cluster itself. When you receive a successful response from this action, DAX immediately begins deleting the cluster; you cannot cancel or revert this action.

    Args:
        cluster_name(str): The name of the cluster to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dax.cluster.delete(ctx, cluster_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dax.cluster.delete cluster_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dax",
        operation="delete_cluster",
        op_kwargs={"ClusterName": cluster_name},
    )


async def describe_all(
    hub,
    ctx,
    cluster_names: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about all provisioned DAX clusters if no cluster identifier is specified, or about a specific DAX cluster if a cluster identifier is supplied. If the cluster is in the CREATING state, only cluster level information will be displayed until all of the nodes are successfully provisioned. If the cluster is in the DELETING state, only cluster level information will be displayed. If nodes are currently being added to the DAX cluster, node endpoint information and creation time for the additional nodes will not be displayed until they are completely provisioned. When the DAX cluster state is available, the cluster is ready for use. If nodes are currently being removed from the DAX cluster, no endpoint information for the removed nodes is displayed.

    Args:
        cluster_names(List, optional): The names of the DAX clusters being described. Defaults to None.
        max_results(int, optional): The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved. The value for MaxResults must be between 20 and 100. Defaults to None.
        next_token(str, optional): An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dax.cluster.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dax.cluster.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dax",
        operation="describe_clusters",
        op_kwargs={
            "ClusterNames": cluster_names,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    cluster_name: str,
    description: str = None,
    preferred_maintenance_window: str = None,
    notification_topic_arn: str = None,
    notification_topic_status: str = None,
    parameter_group_name: str = None,
    security_group_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the settings for a DAX cluster. You can use this action to change one or more cluster configuration parameters by specifying the parameters and the new values.

    Args:
        cluster_name(str): The name of the DAX cluster to be modified.
        description(str, optional): A description of the changes being made to the cluster. Defaults to None.
        preferred_maintenance_window(str, optional): A range of time when maintenance of DAX cluster software will be performed. For example: sun:01:00-sun:09:00. Cluster maintenance normally takes less than 30 minutes, and is performed automatically within the maintenance window. Defaults to None.
        notification_topic_arn(str, optional): The Amazon Resource Name (ARN) that identifies the topic. Defaults to None.
        notification_topic_status(str, optional): The current state of the topic. A value of “active” means that notifications will be sent to the topic. A value of “inactive” means that notifications will not be sent to the topic. Defaults to None.
        parameter_group_name(str, optional): The name of a parameter group for this cluster. Defaults to None.
        security_group_ids(List, optional): A list of user-specified security group IDs to be assigned to each node in the DAX cluster. If this parameter is not specified, DAX assigns the default VPC security group to each node. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dax.cluster.update(ctx, cluster_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dax.cluster.update cluster_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dax",
        operation="update_cluster",
        op_kwargs={
            "ClusterName": cluster_name,
            "Description": description,
            "PreferredMaintenanceWindow": preferred_maintenance_window,
            "NotificationTopicArn": notification_topic_arn,
            "NotificationTopicStatus": notification_topic_status,
            "ParameterGroupName": parameter_group_name,
            "SecurityGroupIds": security_group_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    source: str,
    destination: str,
    protocol: str,
    client_token: str,
    source_ip: str = None,
    destination_ip: str = None,
    destination_port: int = None,
    tag_specifications: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a path to analyze for reachability. Reachability Analyzer enables you to analyze and debug network reachability between two resources in your virtual private cloud (VPC). For more information, see What is Reachability Analyzer.

    Args:
        source_ip(str, optional): The IP address of the Amazon Web Services resource that is the source of the path. Defaults to None.
        destination_ip(str, optional): The IP address of the Amazon Web Services resource that is the destination of the path. Defaults to None.
        source(str): The Amazon Web Services resource that is the source of the path.
        destination(str): The Amazon Web Services resource that is the destination of the path.
        protocol(str): The protocol.
        destination_port(int, optional): The destination port. Defaults to None.
        tag_specifications(List, optional): The tags to add to the path. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        client_token(str): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.insight.path.create(
                ctx, source=value, destination=value, protocol=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.insight.path.create source=value, destination=value, protocol=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_network_insights_path",
        op_kwargs={
            "SourceIp": source_ip,
            "DestinationIp": destination_ip,
            "Source": source,
            "Destination": destination,
            "Protocol": protocol,
            "DestinationPort": destination_port,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
            "ClientToken": client_token,
        },
    )


async def delete(hub, ctx, network_insights_path_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified path.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        network_insights_path_id(str): The ID of the path.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.insight.path.delete(
                ctx, network_insights_path_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.insight.path.delete network_insights_path_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_network_insights_path",
        op_kwargs={
            "DryRun": dry_run,
            "NetworkInsightsPathId": network_insights_path_id,
        },
    )


async def describe_all(
    hub,
    ctx,
    network_insights_path_ids: List = None,
    filters: List = None,
    max_results: int = None,
    dry_run: bool = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your paths.

    Args:
        network_insights_path_ids(List, optional): The IDs of the paths. Defaults to None.
        filters(List, optional): The filters. The following are possible values:   Destination - The ID of the resource.   DestinationPort - The destination port.   Name - The path name.   Protocol - The protocol.   Source - The ID of the resource.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.insight.path.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.insight.path.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_network_insights_paths",
        op_kwargs={
            "NetworkInsightsPathIds": network_insights_path_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "DryRun": dry_run,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    anomaly_detector_arn: str,
    anomaly_group_id: str,
    metric_name: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of anomalous metrics for a measure in an anomaly group.

    Args:
        anomaly_detector_arn(str): The Amazon Resource Name (ARN) of the anomaly detector.
        anomaly_group_id(str): The ID of the anomaly group.
        metric_name(str): The name of the measure field.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        next_token(str, optional): Specify the pagination token that's returned by a previous request to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.anomaly.group.time_sery.list_all(
                ctx, anomaly_detector_arn=value, anomaly_group_id=value, metric_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.anomaly.group.time_sery.list_all anomaly_detector_arn=value, anomaly_group_id=value, metric_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="list_anomaly_group_time_series",
        op_kwargs={
            "AnomalyDetectorArn": anomaly_detector_arn,
            "AnomalyGroupId": anomaly_group_id,
            "MetricName": metric_name,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub,
    ctx,
    interconnect_id: str,
    provider_name: str = None,
    loa_content_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deprecated. Use DescribeLoa instead. Gets the LOA-CFA for the specified interconnect. The Letter of Authorization - Connecting Facility Assignment (LOA-CFA) is a document that is used when establishing your cross connect to Amazon Web Services at the colocation facility. For more information, see Requesting Cross Connects at Direct Connect Locations in the Direct Connect User Guide.

    Args:
        interconnect_id(str): The ID of the interconnect.
        provider_name(str, optional): The name of the service provider who establishes connectivity on your behalf. If you supply this parameter, the LOA-CFA lists the provider name alongside your company name as the requester of the cross connect. Defaults to None.
        loa_content_type(str, optional): The standard media type for the LOA-CFA document. The only supported value is application/pdf. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.interconnect.loa.describe(
                ctx, interconnect_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.interconnect.loa.describe interconnect_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="describe_interconnect_loa",
        op_kwargs={
            "interconnectId": interconnect_id,
            "providerName": provider_name,
            "loaContentType": loa_content_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, fleet_id: str, location: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a fleet's inbound connection permissions. Connection permissions specify the range of IP addresses and port settings that incoming traffic can use to access server processes in the fleet. Game sessions that are running on instances in the fleet must use connections that fall in this range. This operation can be used in the following ways:    To retrieve the inbound connection permissions for a fleet, identify the fleet's unique identifier.    To check the status of recent updates to a fleet remote location, specify the fleet ID and a location. Port setting updates can take time to propagate across all locations.    If successful, a set of IpPermission objects is returned for the requested fleet ID. When a location is specified, a pending status is included. If the requested fleet has been deleted, the result set is empty.  Learn more   Setting up GameLift fleets   Related actions   ListFleets | DescribeEC2InstanceLimits | DescribeFleetAttributes | DescribeFleetCapacity | DescribeFleetEvents | DescribeFleetLocationAttributes | DescribeFleetPortSettings | DescribeFleetUtilization | DescribeRuntimeConfiguration | DescribeScalingPolicies | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet to retrieve port settings for. You can use either the fleet ID or ARN value.
        location(str, optional): A remote location to check for status of port setting updates. Use the AWS Region code format, such as us-west-2. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.port_setting.describe_all(ctx, fleet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.port_setting.describe_all fleet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_fleet_port_settings",
        op_kwargs={"FleetId": fleet_id, "Location": location},
    )


async def update_multiple(
    hub,
    ctx,
    fleet_id: str,
    inbound_permission_authorizations: List = None,
    inbound_permission_revocations: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates permissions that allow inbound traffic to connect to game sessions that are being hosted on instances in the fleet.  To update settings, specify the fleet ID to be updated and specify the changes to be made. List the permissions you want to add in InboundPermissionAuthorizations, and permissions you want to remove in InboundPermissionRevocations. Permissions to be removed must match existing fleet permissions.  If successful, the fleet ID for the updated fleet is returned. For fleets with remote locations, port setting updates can take time to propagate across all locations. You can check the status of updates in each location by calling DescribeFleetPortSettings with a location name.  Learn more   Setting up GameLift fleets   Related actions   CreateFleetLocations | UpdateFleetAttributes | UpdateFleetCapacity | UpdateFleetPortSettings | UpdateRuntimeConfiguration | StopFleetActions | StartFleetActions | PutScalingPolicy | DeleteFleet | DeleteFleetLocations | DeleteScalingPolicy | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet to update port settings for. You can use either the fleet ID or ARN value.
        inbound_permission_authorizations(List, optional): A collection of port settings to be added to the fleet resource. Defaults to None.
        inbound_permission_revocations(List, optional): A collection of port settings to be removed from the fleet resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.port_setting.update_multiple(ctx, fleet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.port_setting.update_multiple fleet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="update_fleet_port_settings",
        op_kwargs={
            "FleetId": fleet_id,
            "InboundPermissionAuthorizations": inbound_permission_authorizations,
            "InboundPermissionRevocations": inbound_permission_revocations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds tags to the specified applied quota. You can include one or more tags to add to the quota.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) for the applied quota. You can get this information by using the Service Quotas console, or by listing the quotas using the list-service-quotas AWS CLI command or the ListServiceQuotas AWS API operation.
        tags(List): The tags that you want to add to the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.service_quotas.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.service_quotas.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="service-quotas",
        operation="tag_resource",
        op_kwargs={"ResourceARN": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes tags from the specified applied quota. You can specify one or more tags to remove.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) for the applied quota that you want to untag. You can get this information by using the Service Quotas console, or by listing the quotas using the list-service-quotas AWS CLI command or the ListServiceQuotas AWS API operation.
        tag_keys(List): The keys of the tags that you want to remove from the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.service_quotas.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.service_quotas.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="service-quotas",
        operation="untag_resource",
        op_kwargs={"ResourceARN": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def remove(hub, ctx, certificate_arn: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Remove one or more tags from an ACM certificate. A tag consists of a key-value pair. If you do not specify the value portion of the tag when calling this function, the tag will be removed regardless of value. If you specify a value, the tag is removed only if it is associated with the specified value.  To add tags to a certificate, use the AddTagsToCertificate action. To view all of the tags that have been applied to a specific ACM certificate, use the ListTagsForCertificate action.

    Args:
        certificate_arn(str): String that contains the ARN of the ACM Certificate with one or more tags that you want to remove. This must be of the form:  arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012  For more information about ARNs, see Amazon Resource Names (ARNs).
        tags(List): The key-value pair that defines the tag to remove.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm.tags.from_certificate.remove(
                ctx, certificate_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm.tags.from_certificate.remove certificate_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm",
        operation="remove_tags_from_certificate",
        op_kwargs={"CertificateArn": certificate_arn, "Tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, workbook_id: str, table_id: str, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     The ListTableColumns API allows you to retrieve a list of all the columns in a table in a workbook.

    Args:
        workbook_id(str): The ID of the workbook that contains the table whose columns are being retrieved.  If a workbook with the specified id could not be found, this API throws ResourceNotFoundException. .
        table_id(str): The ID of the table whose columns are being retrieved.  If a table with the specified id could not be found, this API throws ResourceNotFoundException. .
        next_token(str, optional):  This parameter is optional. If a nextToken is not specified, the API returns the first page of data.   Pagination tokens expire after 1 hour. If you use a token that was returned more than an hour back, the API will throw ValidationException. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.honeycode.table.column.list_all(
                ctx, workbook_id=value, table_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.honeycode.table.column.list_all workbook_id=value, table_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="honeycode",
        operation="list_table_columns",
        op_kwargs={
            "workbookId": workbook_id,
            "tableId": table_id,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    global_cluster_identifier: str,
    source_db_cluster_identifier: str = None,
    engine: str = None,
    engine_version: str = None,
    deletion_protection: bool = None,
    database_name: str = None,
    storage_encrypted: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon DocumentDB global cluster that can span multiple multiple Regions. The global cluster contains one primary cluster with read-write capability, and up-to give read-only secondary clusters. Global clusters uses storage-based fast replication across regions with latencies less than one second, using dedicated infrastructure with no impact to your workload’s performance.  You can create a global cluster that is initially empty, and then add a primary and a secondary to it. Or you can specify an existing cluster during the create operation, and this cluster becomes the primary of the global cluster.   This action only applies to Amazon DocumentDB clusters.

    Args:
        global_cluster_identifier(str): The cluster identifier of the new global cluster.
        source_db_cluster_identifier(str, optional): The Amazon Resource Name (ARN) to use as the primary cluster of the global cluster. This parameter is optional. Defaults to None.
        engine(str, optional): The name of the database engine to be used for this cluster. Defaults to None.
        engine_version(str, optional): The engine version of the global cluster. Defaults to None.
        deletion_protection(bool, optional): The deletion protection setting for the new global cluster. The global cluster can't be deleted when deletion protection is enabled. . Defaults to None.
        database_name(str, optional): The name for your database of up to 64 alpha-numeric characters. If you do not provide a name, Amazon DocumentDB will not create a database in the global cluster you are creating. Defaults to None.
        storage_encrypted(bool, optional): The storage encryption setting for the new global cluster. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.global_cluster.create(
                ctx, global_cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.global_cluster.create global_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="create_global_cluster",
        op_kwargs={
            "GlobalClusterIdentifier": global_cluster_identifier,
            "SourceDBClusterIdentifier": source_db_cluster_identifier,
            "Engine": engine,
            "EngineVersion": engine_version,
            "DeletionProtection": deletion_protection,
            "DatabaseName": database_name,
            "StorageEncrypted": storage_encrypted,
        },
    )


async def delete(hub, ctx, global_cluster_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a global cluster. The primary and secondary clusters must already be detached or deleted before attempting to delete a global cluster.  This action only applies to Amazon DocumentDB clusters.

    Args:
        global_cluster_identifier(str): The cluster identifier of the global cluster being deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.global_cluster.delete(
                ctx, global_cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.global_cluster.delete global_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="delete_global_cluster",
        op_kwargs={"GlobalClusterIdentifier": global_cluster_identifier},
    )


async def describe_all(
    hub,
    ctx,
    global_cluster_identifier: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about Amazon DocumentDB global clusters. This API supports pagination.  This action only applies to Amazon DocumentDB clusters.

    Args:
        global_cluster_identifier(str, optional): The user-supplied cluster identifier. If this parameter is specified, information from only the specific cluster is returned. This parameter isn't case-sensitive. Defaults to None.
        filters(List, optional): A filter that specifies one or more global DB clusters to describe. Supported filters: db-cluster-id accepts cluster identifiers and cluster Amazon Resource Names (ARNs). The results list will only include information about the clusters identified by these ARNs. Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results. . Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous DescribeGlobalClusters request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.global_cluster.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.global_cluster.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="describe_global_clusters",
        op_kwargs={
            "GlobalClusterIdentifier": global_cluster_identifier,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def modify(
    hub,
    ctx,
    global_cluster_identifier: str,
    new_global_cluster_identifier: str = None,
    deletion_protection: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modify a setting for an Amazon DocumentDB global cluster. You can change one or more configuration parameters (for example: deletion protection), or the global cluster identifier by specifying these parameters and the new values in the request.  This action only applies to Amazon DocumentDB clusters.

    Args:
        global_cluster_identifier(str): The identifier for the global cluster being modified. This parameter isn't case-sensitive. Constraints:   Must match the identifier of an existing global cluster.  .
        new_global_cluster_identifier(str, optional): The new identifier for a global cluster when you modify a global cluster. This value is stored as a lowercase string.   Must contain from 1 to 63 letters, numbers, or hyphens The first character must be a letter Can't end with a hyphen or contain two consecutive hyphens   Example: my-cluster2 . Defaults to None.
        deletion_protection(bool, optional): Indicates if the global cluster has deletion protection enabled. The global cluster can't be deleted when deletion protection is enabled. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.global_cluster.modify(
                ctx, global_cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.global_cluster.modify global_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="modify_global_cluster",
        op_kwargs={
            "GlobalClusterIdentifier": global_cluster_identifier,
            "NewGlobalClusterIdentifier": new_global_cluster_identifier,
            "DeletionProtection": deletion_protection,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, identity: str, policy_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified sending authorization policy for the given identity (an email address or a domain). This API returns successfully even if a policy with the specified name does not exist.  This API is for the identity owner only. If you have not verified the identity, this API will return an error.  Sending authorization is a feature that enables an identity owner to authorize other senders to use its identities. For information about using sending authorization, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        identity(str): The identity that is associated with the policy that you want to delete. You can specify the identity by using its name or by using its Amazon Resource Name (ARN). Examples: user@example.com, example.com, arn:aws:ses:us-east-1:123456789012:identity/example.com. To successfully call this API, you must own the identity.
        policy_name(str): The name of the policy to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.identity.policy.delete(
                ctx, identity=value, policy_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.identity.policy.delete identity=value, policy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="delete_identity_policy",
        op_kwargs={"Identity": identity, "PolicyName": policy_name},
    )


async def get_all(hub, ctx, identity: str, policy_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns the requested sending authorization policies for the given identity (an email address or a domain). The policies are returned as a map of policy names to policy contents. You can retrieve a maximum of 20 policies at a time.  This API is for the identity owner only. If you have not verified the identity, this API will return an error.  Sending authorization is a feature that enables an identity owner to authorize other senders to use its identities. For information about using sending authorization, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        identity(str): The identity for which the policies will be retrieved. You can specify an identity by using its name or by using its Amazon Resource Name (ARN). Examples: user@example.com, example.com, arn:aws:ses:us-east-1:123456789012:identity/example.com. To successfully call this API, you must own the identity.
        policy_names(List): A list of the names of policies to be retrieved. You can retrieve a maximum of 20 policies at a time. If you do not know the names of the policies that are attached to the identity, you can use ListIdentityPolicies.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.identity.policy.get_all(
                ctx, identity=value, policy_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.identity.policy.get_all identity=value, policy_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="get_identity_policies",
        op_kwargs={"Identity": identity, "PolicyNames": policy_names},
    )


async def list_all(hub, ctx, identity: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of sending authorization policies that are attached to the given identity (an email address or a domain). This API returns only a list. If you want the actual policy content, you can use GetIdentityPolicies.  This API is for the identity owner only. If you have not verified the identity, this API will return an error.  Sending authorization is a feature that enables an identity owner to authorize other senders to use its identities. For information about using sending authorization, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        identity(str): The identity that is associated with the policy for which the policies will be listed. You can specify an identity by using its name or by using its Amazon Resource Name (ARN). Examples: user@example.com, example.com, arn:aws:ses:us-east-1:123456789012:identity/example.com. To successfully call this API, you must own the identity.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.identity.policy.list_all(ctx, identity=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.identity.policy.list_all identity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="list_identity_policies",
        op_kwargs={"Identity": identity},
    )


async def put(hub, ctx, identity: str, policy_name: str, policy: str) -> Dict:
    r"""
    **Autogenerated function**

    Adds or updates a sending authorization policy for the specified identity (an email address or a domain).  This API is for the identity owner only. If you have not verified the identity, this API will return an error.  Sending authorization is a feature that enables an identity owner to authorize other senders to use its identities. For information about using sending authorization, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        identity(str): The identity that the policy will apply to. You can specify an identity by using its name or by using its Amazon Resource Name (ARN). Examples: user@example.com, example.com, arn:aws:ses:us-east-1:123456789012:identity/example.com. To successfully call this API, you must own the identity.
        policy_name(str): The name of the policy. The policy name cannot exceed 64 characters and can only include alphanumeric characters, dashes, and underscores.
        policy(str): The text of the policy in JSON format. The policy cannot exceed 4 KB. For information about the syntax of sending authorization policies, see the Amazon SES Developer Guide. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.identity.policy.put(
                ctx, identity=value, policy_name=value, policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.identity.policy.put identity=value, policy_name=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="put_identity_policy",
        op_kwargs={"Identity": identity, "PolicyName": policy_name, "Policy": policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    assertion_rule: Dict = None,
    client_token: str = None,
    gating_rule: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a safety rule in a control panel. Safety rules let you add safeguards around enabling and disabling routing controls, to help prevent unexpected outcomes. There are two types of safety rules: assertion rules and gating rules. Assertion rule: An assertion rule enforces that, when a routing control state is changed, the criteria set by the rule configuration is met. Otherwise, the change to the routing control is not accepted. Gating rule: A gating rule verifies that a set of gating controls evaluates as true, based on a rule configuration that you specify. If the gating rule evaluates to true, Amazon Route 53 Application Recovery Controller allows a set of routing control state changes to run and complete against the set of target controls.

    Args:
        assertion_rule(Dict, optional): A new assertion rule for a control panel. Defaults to None.
        client_token(str, optional): Unique client idempotency token. Defaults to None.
        gating_rule(Dict, optional): A new gating rule for a control panel. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.safety_rule.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.safety_rule.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="create_safety_rule",
        op_kwargs={
            "AssertionRule": assertion_rule,
            "ClientToken": client_token,
            "GatingRule": gating_rule,
        },
    )


async def delete(hub, ctx, safety_rule_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a safety rule./>

    Args:
        safety_rule_arn(str): The request body that you include when you update a safety rule.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.safety_rule.delete(
                ctx, safety_rule_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.safety_rule.delete safety_rule_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="delete_safety_rule",
        op_kwargs={"SafetyRuleArn": safety_rule_arn},
    )


async def describe(hub, ctx, safety_rule_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the safety rules (that is, the assertion rules and gating rules) for the routing controls in a control panel.

    Args:
        safety_rule_arn(str): The request body that you include when you update a safety rule.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.safety_rule.describe(
                ctx, safety_rule_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.safety_rule.describe safety_rule_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="describe_safety_rule",
        op_kwargs={"SafetyRuleArn": safety_rule_arn},
    )


async def list_all(
    hub, ctx, control_panel_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    List the safety rules (the assertion rules and gating rules) that you've defined for the routing controls in a control panel.

    Args:
        control_panel_arn(str): The Amazon Resource Name (ARN) of the control panel that you're getting details for.
        max_results(int, optional): The number of objects that you want to return with this call. Defaults to None.
        next_token(str, optional): The token that identifies which batch of results you want to see. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.safety_rule.list_all(
                ctx, control_panel_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.safety_rule.list_all control_panel_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="list_safety_rules",
        op_kwargs={
            "ControlPanelArn": control_panel_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub, ctx, assertion_rule_update: Dict = None, gating_rule_update: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Update a safety rule (an assertion rule or gating rule) for the routing controls in a control panel. You can only update the name and the waiting period for a safety rule. To make other updates, delete the safety rule and create a new safety rule.

    Args:
        assertion_rule_update(Dict, optional): An update to an assertion rule. You can update the name or the evaluation period (wait period). If you don't specify one of the items to update, the item is unchanged. Defaults to None.
        gating_rule_update(Dict, optional): Update to a gating rule. You can update the name or the evaluation period (wait period). If you don't specify one of the items to update, the item is unchanged. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.safety_rule.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.safety_rule.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="update_safety_rule",
        op_kwargs={
            "AssertionRuleUpdate": assertion_rule_update,
            "GatingRuleUpdate": gating_rule_update,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, stack_id: str = None, app_ids: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Requests a description of a specified set of apps.  This call accepts only one resource-identifying parameter.   Required Permissions: To use this action, an IAM user must have a Show, Deploy, or Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        stack_id(str, optional): The app stack ID. If you use this parameter, DescribeApps returns a description of the apps in the specified stack. Defaults to None.
        app_ids(List, optional): An array of app IDs for the apps to be described. If you use this parameter, DescribeApps returns a description of the specified apps. Otherwise, it returns a description of every app. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.apps.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.apps.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_apps",
        op_kwargs={"StackId": stack_id, "AppIds": app_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


__func_alias__ = {"set_": "set"}


async def set_(hub, ctx, pipeline_id: str, object_ids: List, status: str) -> None:
    r"""
    **Autogenerated function**

    Requests that the status of the specified physical or logical pipeline objects be updated in the specified pipeline. This update might not occur immediately, but is eventually consistent. The status that can be set depends on the type of object (for example, DataNode or Activity). You cannot perform this operation on FINISHED pipelines and attempting to do so returns InvalidRequestException.

    Args:
        pipeline_id(str): The ID of the pipeline that contains the objects.
        object_ids(List): The IDs of the objects. The corresponding objects can be either physical or components, but not a mix of both types.
        status(str): The status to be set on all the objects specified in objectIds. For components, use PAUSE or RESUME. For instances, use TRY_CANCEL, RERUN, or MARK_FINISHED.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datapipeline.status.set(
                ctx, pipeline_id=value, object_ids=value, status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datapipeline.status.set pipeline_id=value, object_ids=value, status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datapipeline",
        operation="set_status",
        op_kwargs={
            "pipelineId": pipeline_id,
            "objectIds": object_ids,
            "status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a device instance that belongs to a private device fleet.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the instance you're requesting information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.device.instance.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.device.instance.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="get_device_instance",
        op_kwargs={"arn": arn},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the private device instances associated with one or more AWS accounts.

    Args:
        max_results(int, optional): An integer that specifies the maximum number of items you want to return in the API response. Defaults to None.
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.device.instance.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.device.instance.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="list_device_instances",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def update(
    hub, ctx, arn: str, profile_arn: str = None, labels: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates information about a private device instance.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the device instance.
        profile_arn(str, optional): The ARN of the profile that you want to associate with the device instance. Defaults to None.
        labels(List, optional): An array of strings that you want to associate with the device instance. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.device.instance.update(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.device.instance.update arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="update_device_instance",
        op_kwargs={"arn": arn, "profileArn": profile_arn, "labels": labels},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, template_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the template information for a specific object type. A template is a predefined ProfileObjectType, such as “Salesforce-Account” or “Salesforce-Contact.” When a user sends a ProfileObject, using the PutProfileObject API, with an ObjectTypeName that matches one of the TemplateIds, it uses the mappings from the template.

    Args:
        template_id(str): A unique identifier for the object template.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.profile.object_.type_.template.get(
                ctx, template_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.profile.object_.type_.template.get template_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="get_profile_object_type_template",
        op_kwargs={"TemplateId": template_id},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the template information for object types.

    Args:
        next_token(str, optional): The pagination token from the previous ListObjectTypeTemplates API call. Defaults to None.
        max_results(int, optional): The maximum number of objects returned per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.profile.object_.type_.template.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.profile.object_.type_.template.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="list_profile_object_type_templates",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, anomaly_group_id: str, anomaly_detector_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns details about a group of anomalous metrics.

    Args:
        anomaly_group_id(str): The ID of the anomaly group.
        anomaly_detector_arn(str): The Amazon Resource Name (ARN) of the anomaly detector.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.anomaly.group.init.get(
                ctx, anomaly_group_id=value, anomaly_detector_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.anomaly.group.init.get anomaly_group_id=value, anomaly_detector_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="get_anomaly_group",
        op_kwargs={
            "AnomalyGroupId": anomaly_group_id,
            "AnomalyDetectorArn": anomaly_detector_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, resource_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of tags for the specified AWS CloudHSM cluster. This is a paginated operation, which means that each response might contain only a subset of all the tags. When the response contains only a subset of tags, it includes a NextToken value. Use this value in a subsequent ListTags request to get more tags. When you receive a response with no NextToken (or an empty or null value), that means there are no more tags to get.

    Args:
        resource_id(str): The cluster identifier (ID) for the cluster whose tags you are getting. To find the cluster ID, use DescribeClusters.
        next_token(str, optional): The NextToken value that you received in the previous response. Use this value to get more tags. Defaults to None.
        max_results(int, optional): The maximum number of tags to return in the response. When there are more tags than the number you specify, the response contains a NextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsmv2.tags.list(ctx, resource_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsmv2.tags.list resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsmv2",
        operation="list_tags",
        op_kwargs={
            "ResourceId": resource_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )
